@@ -1,6 +1,9 @@
 package App::NetdiscoX::Web::Plugin::RANCID;
 
-our $VERSION = '2.004000';
+use strict;
+use warnings;
+
+our $VERSION = '2.005000';
 
 use Dancer ':syntax';
 
@@ -35,21 +38,37 @@ hook 'before_template' => sub {
     my $rancid = $config->{rancid};
 
     $rancid->{groups}      ||= {};
+    $rancid->{excluded}    ||= [];
     $rancid->{by_ip}       ||= [];
     $rancid->{by_hostname} ||= [];
 
+    if (check_acl(get_device($device->{ip}),$rancid->{excluded})) {
+        session rancid_display => 0;
+    } else {
+        session rancid_display => 1;
+    }
+
     foreach my $g (keys %{ $rancid->{groups} }) {
         if (check_acl( get_device($device->{ip}), $rancid->{groups}->{$g} )) {
             $tokens->{rancidgroup} = $g;
-            $tokens->{ranciddevice} = $device->{ip}
-              if 0 < scalar grep {$_ eq $g} @{ $rancid->{by_ip} };
-            $tokens->{ranciddevice} =~ s/$domain_suffix$//
-              if 0 < scalar grep {$_ eq $g} @{ $rancid->{by_hostname} };
+            if (check_acl( get_device($device->{ip}),$rancid->{by_hostname})) {
+                $tokens->{ranciddevice} =~ s/$domain_suffix$//;
+            } elsif (check_acl( get_device($device->{ip}), $rancid->{by_ip})) {
+                $tokens->{ranciddevice} = $device->{ip};
+            }
             last;
         }
     }
 };
 
+1;
+
+__END__
+
+=pod
+
+=cut
+
 =head1 NAME
 
 App::NetdiscoX::Web::Plugin::RANCID - Link to device backups in RANCID/WebSVN
@@ -57,18 +76,18 @@ App::NetdiscoX::Web::Plugin::RANCID - Link to device backups in RANCID/WebSVN
 =head1 SYNOPSIS
 
  # in your ~/environments/deployment.yml file
-  
+
  extra_web_plugins:
    - X::RANCID
- 
+
  plugin_rancid:
-   location: 'https://websvn-server.example.com/rancid/%DEVICE%'
+   location: 'https://websvn.example.com/websvn/filedetails.php?repname=rancid&path=/%GROUP%/configs/%DEVICE%'
 
 =head1 Description
 
 This is a plugin for the L<App::Netdisco> network management application.
 It adds a row to the Device Details page named "RANCID" with a link to
-your local RANCID/WebSVN installation hosting the device configuation
+your local RANCID/WebSVN installation hosting the device configuration
 backups.
 
 =head1 Configuration
@@ -90,15 +109,16 @@ a RANCID web page, only with the device name or ip changed to be
 
 The text "C<%GROUP%>" will be replaced with the group name for this device, if
 known to Netdisco. This uses the same configuration as for
-L<netdisco-rancid-export>, an example of which is below:
+L<App::Netdisco::Worker::Plugin::MakeRancidConf>, an example of which is below:
 
  rancid:
-   by_ip:       [ other ]
-   by_hostname: [ other2 ]
+   by_ip:           [ other ]
+   by_hostname:     'group:grp-reversedns'
    groups:
-     switch: [ 'name:.*[Ss][Ww].*' ]
-     rtr:    [ 'name:[rR]tr.*' ]
-     ap:     [ 'name:[aA][pP].*' ]
+     aerohive:      'group:grp-hiveos'
+     switch:        [ 'name:.*[Ss][Ww].*' ]
+     rtr:           [ 'name:[rR]tr.*' ]
+     ap:            [ 'name:[aA][pP].*' ]
 
 Briefly, each group value is a list of rules for matching devices similar to
 those used by any C<*_only> configuration item. You can provide an IP, subnet
@@ -109,6 +129,7 @@ The device DNS name is used, or if missing the device SNMP sysName. Adding the
 group to the list in C<by_ip> will make the link include the device IP
 instead of the name. Adding the group to the list in C<by_hostname> will
 use the device FQDN minus the C<domain_suffix> config item (i.e. the hostname).
+C<by_hostname> will take precedence over C<by_ip>.
 
 =head2 open_in_same_window
 
@@ -117,14 +138,24 @@ Value: Boolean. Default: false.
 If set to true, the hyperlink is configured to open the WebSVN page in the
 same browser window or tab as Netdisco.
 
+=head1 SEE ALSO
+
+L<App::Netdisco::Worker::Plugin::MakeRancidConf>
+
+L<http://www.shrubbery.net/rancid/>
+
+L<https://websvnphp.github.io/>
+
+L<https://github.com/viewvc/viewvc/>
+
 =head1 AUTHOR
 
 Oliver Gorwits <oliver@cpan.org>
 
-=head1 COPYRIGHT AND LICENSE
- 
-This software is copyright (c) 2013 by The Netdisco Developer Team.
- 
+=head1 LICENSE AND COPYRIGHT
+
+This software is copyright (c) 2013,2019 by The Netdisco Developer Team.
+
  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions are met:
      * Redistributions of source code must retain the above copyright
@@ -135,7 +166,7 @@ This software is copyright (c) 2013 by The Netdisco Developer Team.
      * Neither the name of the Netdisco Project nor the
        names of its contributors may be used to endorse or promote products
        derived from this software without specific prior written permission.
- 
+
  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
  WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
@@ -148,5 +179,3 @@ This software is copyright (c) 2013 by The Netdisco Developer Team.
  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 =cut
-
-true;
